@@ -76,15 +76,23 @@ def parse_to_python_object(string):
             ip, port, src = match.groups()
             yield IP(ip, port), src
     
-    datablock_regex = re.compile(r"(\[.*\])(.*)", re.DOTALL)        
+    datablock_regex = re.compile(r"(\[.*?\])(.*)", re.DOTALL)        
 
     def parse_datablock(src):
         match = datablock_regex.match(src)
         if match is not None:
             sert, src = match.groups()
             yield sert, src
+    
+    password_regex = re.compile(r"\"(\\\\?x?0{1,}1.*?)\"(;.*)", re.DOTALL)        
 
-    quoted_regex = re.compile(r"\"(.*?)(?:(?<!\\)\"|\"(?=$|; ?(?:\"|})))(.*)", re.DOTALL)#r"\"(.*?(?<!\\))\"(.*)"     \"(.*?(?:\"\b.+)?)\"(.*)    \"(.*?)(?:(?<!\\)\"|\"$)(.*)
+    def parse_password(src):
+        match = password_regex.match(src)
+        if match is not None:
+            pwd, src = match.groups()
+            yield pwd, src
+
+    quoted_regex = re.compile(r"\"(.*?)(?:(?<!\\)\"|\"(?=$|;\s?(?:\"|}|\b)))(.*)", re.DOTALL)#r"\"(.*?(?<!\\))\"(.*)"     \"(.*?(?:\"\b.+)?)\"(.*)    \"(.*?)(?:(?<!\\)\"|\"$)(.*)     \"(.*?)(?:(?<!\\)\"|\"(?=$|; ?(?:\"|})))(.*)
     unquoted_regex = re.compile(r"([\w.@#-]+)(.*)", re.DOTALL)
 
     def parse_string(src):
@@ -121,6 +129,7 @@ def parse_to_python_object(string):
             parse_num_null(src),
             parse_ip(src),
             parse_datablock(src),
+            # parse_password(src),
             parse_string(src),
             parse_xml(src),
             parse_array(src),
@@ -253,4 +262,4 @@ def parse_to_CGP_object(python_object):
     elif python_object is None:
         return "#NULL#" # "null"
         
-    return result
\ No newline at end of file
+    return result
